@@ -127,7 +127,10 @@ class AoisoLogic:
 
     def store_node_text(self,iter,text):
         node = self.model.get_value(iter,1)
-        node.text = text
+        if node == None:
+            print "Node is None"
+        else:
+            node.text = text
 
     def store_node_title(self,iter,title):
         node = self.model.get_value(iter,1)
